[commit: ghc] wip/nfs-locking: Rename project executable to hadrian. (affe0bd)

git at git.haskell.org git at git.haskell.org
Fri Oct 27 00:56:42 UTC 2017


Repository : ssh://git@git.haskell.org/ghc

On branch  : wip/nfs-locking
Link       : http://ghc.haskell.org/trac/ghc/changeset/affe0bd9add35be2a801a68a0cc1309f2bdb176a/ghc

>---------------------------------------------------------------

commit affe0bd9add35be2a801a68a0cc1309f2bdb176a
Author: Andrey Mokhov <andrey.mokhov at gmail.com>
Date:   Wed Apr 27 00:50:27 2016 +0100

    Rename project executable to hadrian.


>---------------------------------------------------------------

affe0bd9add35be2a801a68a0cc1309f2bdb176a
 build.cabal-new.sh | 8 ++++----
 build.cabal.sh     | 2 +-
 build.stack.sh     | 2 +-
 hadrian.cabal      | 2 +-
 src/Environment.hs | 2 +-
 5 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/build.cabal.sh b/build.cabal.sh
index 5f20c1b..f2e320e 100755
--- a/build.cabal.sh
+++ b/build.cabal.sh
@@ -40,7 +40,7 @@ if ! ( cabal sandbox hc-pkg list 2>&1 > /dev/null ); then
         --disable-shared
 fi
 
-cabal run ghc-shake --             \
+cabal run hadrian --               \
     --lint                         \
     --directory "$absoluteRoot/.." \
     --colour                       \
diff --git a/build.stack.sh b/build.stack.sh
index 578e7eb..b5607b1 100755
--- a/build.stack.sh
+++ b/build.stack.sh
@@ -33,7 +33,7 @@ cd "$absoluteRoot"
 
 stack build --no-library-profiling
 
-stack exec ghc-shake --            \
+stack exec hadrian --              \
     --lint                         \
     --directory "$absoluteRoot/.." \
     --colour                       \
diff --git a/hadrian.cabal b/hadrian.cabal
index a2df30a..4bf5a4c 100644
--- a/hadrian.cabal
+++ b/hadrian.cabal
@@ -14,7 +14,7 @@ source-repository head
     type:     git
     location: https://github.com/snowleopard/hadrian
 
-executable ghc-shake
+executable hadrian
     main-is:             Main.hs
     hs-source-dirs:      src
     other-modules:       Base
diff --git a/src/Environment.hs b/src/Environment.hs
index e674f83..d4d9853 100644
--- a/src/Environment.hs
+++ b/src/Environment.hs
@@ -13,7 +13,7 @@ setupEnvironment = do
 
     -- in MinGW if PWD is set to a Windows "C:\\" style path then configure
     -- `pwd` will return the Windows path, and then modifying $PATH will fail.
-    -- See https://github.com/snowleopard/shaking-up-ghc/issues/189 for details.
+    -- See https://github.com/snowleopard/hadrian/issues/189 for details.
     unsetEnv "PWD"
 
     -- On Windows, some path variables start a prefix like "C:\\" which may



More information about the ghc-commits mailing list
diff --git a/build.cabal-new.sh b/build.cabal-new.sh
index 96c194e..bca8c7c 100755
--- a/build.cabal-new.sh
+++ b/build.cabal-new.sh
@@ -38,16 +38,16 @@ mkdir -p "$root/.shake"
 # Notes/Random thoughts:
 #
 # - if ghc.git had a top-level `cabal.project` file, we could maybe avoid the
 # boilerplate above, as we could simply say `cabal exec ghc-shake` from within
 # any GHC folder not shadowed by a nearer shadowing `cabal.project` file.
 
 pushd "$root/"
 
-cabal new-build --disable-profiling --disable-documentation -j exe:ghc-shake
+cabal new-build --disable-profiling --disable-documentation -j exe:hadrian
 
-PKGVER="$(awk '/^version:/ { print $2 }' shaking-up-ghc.cabal)"
+PKGVER="$(awk '/^version:/ { print $2 }' hadrian.cabal)"
 
-cp -v "$root/dist-newstyle/build/shaking-up-ghc-${PKGVER}/build/ghc-shake/ghc-shake" \
+cp -v "$root/dist-newstyle/build/hadrian-${PKGVER}/build/hadrian/hadrian" \
       "$root/.shake/build"
 
 popd
@@ -38,16 +38,16 @@ mkdir -p "$root/.shake"
 #
 # - if ghc.git had a top-level `cabal.project` file, we could maybe avoid the
-# boilerplate above, as we could simply say `cabal exec ghc-shake` from within
+# boilerplate above, as we could simply say `cabal exec hadrian` from within
 # any GHC folder not shadowed by a nearer shadowing `cabal.project` file.
 